boofun.core.optimizations
=========================

.. automodule:: boofun.core.optimizations


   .. rubric:: Functions

   .. autosummary::

      BEST_INFLUENCES
      BEST_WHT
      batch_evaluate
      cached_computation
      fast_walsh_hadamard
      fast_walsh_hadamard_numba
      get_best_wht_implementation
      get_global_cache
      memoize_method
      noise_stability_from_fourier
      parallel_batch_fourier
      parallel_batch_influences
      vectorized_influences_from_fourier
      vectorized_influences_numba
      vectorized_total_influence_from_fourier
      vectorized_total_influence_numba
      vectorized_truth_table_to_pm

   .. rubric:: Classes

   .. autosummary::

      ComputeCache
      LazyFourierCoefficients
